*+--------------------------------------------------------------------
*+
*+ Source Module => d:\ALASKA\6\\LUTZMAIN.PRG
*+
*+    Copyright(C) 1983-2020 by Auge & Ohr
*+
*+    Functions: Procedure AppSys()
*+               Procedure Main()
*+               Static Function AskQuit()
*+               Static Procedure DialogMenu()
*+               Function NACHCLP()
*+               Function VONCLP()
*+               Function GetCursorPos()
*+               Function PopAbsPos()
*+               Function GetTitleBarHeight()
*+
*+    Reformatted by Click! 2.05.30 on Jun-8-2020 at  5:11 am
*+
*+--------------------------------------------------------------------

#include "Appevent.ch"
#include "Common.ch"
#include "Gra.ch"
#include "Xbp.ch"
#include "DLL.ch"

#define MENUITEM_SEPARATOR    {NIL, NIL, XBPMENUBAR_MIS_SEPARATOR, 0}
#define BORDER_SIZE           1

*+--------------------------------------------------------------------
*+
*+    Procedure AppSys()
*+
*+--------------------------------------------------------------------
*+
PROCEDURE AppSys

RETURN

*+--------------------------------------------------------------------
*+
*+    Procedure Main()
*+
*+--------------------------------------------------------------------
*+
PROCEDURE Main

LOCAL nEvent, mp1, mp2, oXbp
LOCAL oDlg, lExit := .F.
LOCAL oCrt

   oDlg := XbpDialog() :new( AppDesktop(),, { 0, 0 }, { 800, 600 },, .F. )
   oDlg:title := "GUI Parent for CRT"
   oDlg:taskList := .T.
   oDlg:clipSiblings := .T.
   oDlg:close := { || IF( AskQuit( oCrt ), lExit := .T., Msgbox( "close CRT first" ) ) }
   oDlg:maxButton := .F.
   oDlg:create()
   oDlg:drawingArea:setFontCompoundName( "14.Helv" )

   DialogMenu( oDlg, oCrt )

   Centercontrol( oDlg )
   oDlg:show()
   SetAppFocus( oDlg )

   DO WHILE !lExit = .T.
      nEvent := AppEvent( @mp1, @mp2, @oXbp )
      oXbp:handleEvent( nEvent, mp1, mp2 )
   ENDDO
RETURN

*+--------------------------------------------------------------------
*+
*+    Static Function AskQuit()
*+
*+    Called from ( lutzmain.prg )   1 - procedure main()
*+
*+--------------------------------------------------------------------
*+
STATIC FUNCTION AskQuit( oCrt )

LOCAL lRet
   IF VALTYPE( oCrt ) = "O"
      lRet := .F.
   ELSE
      lRet := .T.
   ENDIF

RETURN lRet

*+--------------------------------------------------------------------
*+
*+    Static Procedure DialogMenu()
*+
*+    Called from ( lutzmain.prg )   1 - procedure main()
*+
*+--------------------------------------------------------------------
*+
STATIC PROCEDURE DialogMenu( oDlg, oCrt )

LOCAL oMenuBar := oDlg:menuBar()
LOCAL oMenu    := XbpMenu() :new( oMenuBar )

   /*
   * When the MDI window gets focus, it passes itself to SetAppWindow()
   * This is a prerequisite for the WinMenu() function below.
   */
   oDlg:setDisplayFocus := { | mp1, mp2, obj | IF( VALTYPE( oCrt ) = "O", SetAppWindow( oCrt ), SetAppWindow( obj ) ) }

   oMenu:title := "~Open"
   oMenu:create()

   oMenu:addItem( { "~Lutz CRT", { || Child_Crt_1( oDlg, oCrt ) } } )
   oMenu:addItem( MENUITEM_SEPARATOR )
   oMenu:addItem( { "~Exit", { || PostAppEvent( xbeP_Close,,, oDlg ) } } )
   oMenuBar:addItem( { oMenu, NIL } )

RETURN

*+--------------------------------------------------------------------
*+
*+    Function NACHCLP()
*+
*+    Called from ( lutz.prg )   1 - procedure child_crt_1()
*+
*+--------------------------------------------------------------------
*+
FUNCTION NACHCLP( cText )

LOCAL oClipBoard

   IF PCOUNT() = 0
      MSGBOX( "durch das markieren wurde der Bereich automatisch kopiert" )
   ELSE
      IF !EMPTY( cText )
         oClipBoard := XbpClipBoard() :new() :create()
         oClipBoard:open()
         oClipBoard:clear()
         oClipBoard:setBuffer( cText, XBPCLPBRD_TEXT )
         oClipBoard:close()
         oClipBoard:destroy()
      ENDIF
   ENDIF
RETURN .T.

*+--------------------------------------------------------------------
*+
*+    Function VONCLP()
*+
*+    Called from ( lutz.prg )   1 - procedure child_crt_1()
*+
*+--------------------------------------------------------------------
*+
FUNCTION VONCLP()

LOCAL oClipBoard
LOCAL aFormats
LOCAL cText      := ""

   oClipBoard := XbpClipBoard() :new() :create()
   oClipBoard:open()
   aFormats := OClipBoard:queryFormats()
   IF ASCAN( aFormats, XBPCLPBRD_TEXT ) > 0
      cText := ALLTRIM( oClipBoard:getBuffer( XBPCLPBRD_TEXT ) )
      IF !EMPTY( cText )
         KEYBOARD ( cText )
      ENDIF
      oClipBoard:close()
      oClipBoard:destroy()
   ENDIF
RETURN .T.

*+--------------------------------------------------------------------
*+
*+    Function GetCursorPos()
*+
*+    Called from ( lutzmain.prg )   1 - function popabspos()
*+
*+--------------------------------------------------------------------
*+
FUNCTION GetCursorPos()

LOCAL sPoint := REPLICATE( CHR( 0 ), 8 )
LOCAL nX     := 0
LOCAL nY     := 0

STATIC GetCursorPos

   IF GetCursorPos = NIL
      GetCursorPos := DllPrepareCall( "user32.dll", DLL_STDCALL, "GetCursorPos" )
   ENDIF

   DllExecuteCall( GetCursorPos, @sPoint )

   nX := BIN2L( SUBSTR( sPoint, 1, 4 ) )
   nY := BIN2L( SUBSTR( sPoint, 5, 4 ) )

   nY := ( - 1 * nY ) + APPDESKTOP() :CURRENTSIZE() [2] - 1           // Top-Down

RETURN ( { nX, nY } )

*+--------------------------------------------------------------------
*+
*+    Function PopAbsPos()
*+
*+    Called from ( lutz.prg )   1 - procedure child_crt_1()
*+
*+--------------------------------------------------------------------
*+
FUNCTION PopAbsPos( oMainDlg )

LOCAL aPos := { 0, 0 }
LOCAL aDlg := oMainDlg:currentpos()
LOCAL aAbs := GetCursorPos()
   aPos[ 1 ] := aAbs[ 1 ] - aDlg[ 1 ]
   aPos[ 2 ] := aAbs[ 2 ] - aDlg[ 2 ]
RETURN aPos

*+--------------------------------------------------------------------
*+
*+    Function GetTitleBarHeight()
*+
*+    Called from ( lutz.prg )   1 - procedure child_crt_1()
*+                                   1 - static procedure setnewfont()
*+
*+--------------------------------------------------------------------
*+
FUNCTION GetTitleBarHeight( o )

RETURN ( o:currentSize() [ 2 ] - o:drawingArea:currentSize() [ 2 ] - ;
         ( 2 * BORDER_SIZE ) - 1 )

//
//
//

*+ EOF: LUTZMAIN.PRG
